@@ -35,10 +35,14 @@ def get_all_file_mappings():
     submod_doc_files = {}
     for root, dirs, files in src_walk:
         dd = os.path.normpath(root).split(os.sep)
-        pkg_idx = dd.index(CONFIG.package_name)
-        if CONFIG.package_name in dd[(pkg_idx + 1) :]:
-            pkg_idx += dd[(pkg_idx + 1) :].index(CONFIG.package_name)
-        subpkg_unfolded = dd[pkg_idx:]
+        dd_rev = list(reversed(dd))
+        # print(dd_rev)
+        pkg_idx = dd_rev.index(CONFIG.package_name)
+        # if CONFIG.package_name in dd[(pkg_idx + 1) :]:
+        #    pkg_idx += dd[(pkg_idx + 1) :].index(CONFIG.package_name)
+        subpkg_unfolded = list(reversed(dd_rev[: (pkg_idx + 1)]))
+        # print(subpkg_unfolded)
+        # subpkg_unfolded = dd[pkg_idx:]
 
         try:
             dirs.remove("__pycache__")
